import astropy.units as u
import astropy.wcs
import numpy as np
from astropy.nddata import StdDevUncertainty

from ndcube import NDCube

# Define data array.
data = np.random.rand(4, 4, 5)

# Define WCS transformations in an astropy WCS object.
wcs = astropy.wcs.WCS(naxis=3)
wcs.wcs.ctype = 'WAVE', 'HPLT-TAN', 'HPLN-TAN'
wcs.wcs.cunit = 'Angstrom', 'deg', 'deg'
wcs.wcs.cdelt = 0.2, 0.5, 0.4
wcs.wcs.crpix = 0, 2, 2
wcs.wcs.crval = 10, 0.5, 1
wcs.wcs.cname = 'wavelength', 'HPC lat', 'HPC lon'

# Define mask.  Initially set all elements unmasked.
mask = np.zeros_like(data, dtype=bool)
mask[-1, -1][:] = True  # Now mask some values.
# Define uncertainty, metadata and unit.
uncertainty = StdDevUncertainty(np.sqrt(np.abs(data)))
meta = {"Description": "This is example NDCube metadata."}
unit = u.ct

# Instantiate NDCube with supporting data.
my_cube = NDCube(data, wcs=wcs, uncertainty=uncertainty, mask=mask, meta=meta, unit=unit)
